{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Password Reset Email Sent' %} - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Password Reset Email Sent' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Password Reset Email Sent' %}</h1>
<p>{% trans "You will receive an email shortly that will contain instructions on how to reset your password." %}</p>

{% endblock %}
