{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Sign Out' %} - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Sign Out' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Sign Out' %}</h1>

<p>{% trans 'Are you sure you want to sign out?' %}</p>

<form method="post" action="{% url 'umanage_logout' %}" class="form-umanage">
    {% csrf_token %}
    <div>
        <input class="btn btn-primary" type="submit" value="{% trans 'Sign Out' %}" />
    </div>
</form>
{% endblock %}
