{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Password Successfully Updated' %} - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Password Successfully Updated' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Password Successfully Updated' %}</h1>
<p>{% trans "Your password has been successfully updated!" %}</p>
<p><a href="{% url 'umanage_account_view' %}" class="btn btn-primary">{% trans 'Back to account' %}</a></p>
{% endblock %}
