{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Token Expired' %}  - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Token Expired' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Token Expired' %}</h1>
<p>{% trans 'The forgot password token is expired for 1 of 2 reasons:' %}</p>
<ol>
    <li>{% trans 'The password has already been successfully changed' %}</li>
    <li>{% trans 'The token is beyond the time alloted to make the change. If this is the case, please go through the forgot password process again.' %}</li>
</ol>
{% endblock %}
