{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Forgot Password' %} - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Forgot Password' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Forgot Password' %}</h1>

<p>{% trans "Please enter your email or username below and an email will be sent to you with a set of instructions on how to reset your password." %}</p>

<form method="post" action="{% url 'umanage_forgot_password' %}" class="form-umanage form-horizontal">
    {% csrf_token %}
    {{ form|render_umanage_form }}
    <div class="form-group umanage-button-container">
        <div class="col-sm-offset-2 col-sm-10">
            <button type="submit" class="btn btn-primary">Send</button>
            <a href="/">cancel</a>
        </div>
    </div>
</form>
{% endblock %}
