{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Change Email Expired' %}  - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Change Email Expired' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Change Email Expired' %}</h1>
<p>{% trans 'The change email token is expired for 1 of 2 reasons:' %}</p>
<ol>
    <li>{% trans 'The email has already been successfully activated' %}</li>
    <li>{% trans 'The change email token has expired.  If this is the case, please go through the change email process again.' %}</li>
</ol>
<p><a href="{% url 'umanage_account_view' %}" class="btn btn-primary">{% trans 'Back to account' %}</a></p>
{% endblock %}
