{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}Change Password - {% endblock %}

{% block breadcrumb %}
    <li>Change Password</li>
{% endblock %}

{% block umanage_content %}
<h1>Change Password</h1>

<p>{% trans "Please enter your old password, for security purposes, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

<form method="post" action="{% url 'umanage_change_password' %}" class="form-umanage form-horizontal">
    {% csrf_token %}
    {{ form|render_umanage_form }}
    <div class="form-group umanage-button-container">
        <div class="col-sm-offset-2 col-sm-10">
            <button type="submit" class="btn btn-primary">Save</button>
            <a href="/">cancel</a>
        </div>
    </div>
</form>
{% endblock %}
