{% extends UMANAGE_BASE_TEMPLATE %}
{% comment %}
This is a gateway template that allows a 3rd party app (django-umanage) to have
templates that work with an another system.

By setting the UMANAGE_BASE_TEMPLATE context variable, this allows the app to be
extending by an existing system's templates. 
{% endcomment %}