{% extends 'umanage/base_umanage.html' %}
{% load i18n umanage %}
{% block page_title %}{% trans 'Account Activated' %} - {% endblock %}

{% block breadcrumb %}
    <li>{% trans 'Account Activated' %}</li>
{% endblock %}

{% block umanage_content %}
<h1>{% trans 'Account Activated' %}</h1>
<p>{% trans "Your account has been successfully activated!" %}</p>
{% if user.is_authenticated %}
<p><a href="/" class="btn btn-primary">Go to home page</a></p>
{% else %}
<p><a href="{{ login_url }}" class="btn btn-primary">Login</a></p>
{% endif %}

{% endblock %}
